@@ -2,12 +2,14 @@ package Rose::DB::Object::Cached;
 
 use strict;
 
+use Carp();
+
 use Rose::DB::Object;
 our @ISA = qw(Rose::DB::Object);
 
 use Rose::DB::Object::Constants qw(STATE_IN_DB);
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 our $Debug = 0;
 
@@ -19,7 +21,7 @@ use constant UK_SEP => "\0\0";
 # the stringified multi-column unique key vaue
 use constant UNDEF  => "\1\2undef\2\1";
 
-my $save_object = sub
+sub __xrdbopriv_save_object
 {
   my($self) = shift;
 
@@ -28,8 +30,16 @@ my $save_object = sub
 
   no strict 'refs';
 
+  my $ttl_secs = $class->cache_expires_in || 0;
+  my $loaded = $ttl_secs ? time : 0;
+
   ${"${class}::Objects_By_Id"}{$pk} = $self;
 
+  if($ttl_secs)
+  {
+    ${"${class}::Objects_By_Id_Loaded"}{$pk} = $loaded;
+  }
+
   foreach my $cols ($self->meta->unique_keys)
   {
     no warnings;
@@ -39,13 +49,25 @@ my $save_object = sub
 
     ${"${class}::Objects_By_Key"}{$key_name}{$key_value} = $self;
     ${"${class}::Objects_Keys"}{$pk}{$key_name} = $key_value;
+
+    if($ttl_secs)
+    {
+      ${"${class}::Objects_By_Key_Loaded"}{$key_name}{$key_value} = $loaded;
+    }
   }
 };
 
-my $get_object = sub
+# This constant is not arbitrary.  It must be defined and false.
+# I'm playing games with return values, but this is all internal
+# anyway and can change at any time.
+use constant CACHE_EXPIRED => 0;
+
+sub __xrdbopriv_get_object
 {
   my($class) = ref $_[0] || $_[0];
 
+  my $ttl_secs = $class->cache_expires_in;
+
   if(@_ == 2)
   {
     my($pk) = $_[1];
@@ -55,6 +77,12 @@ my $get_object = sub
 
     if(${"${class}::Objects_By_Id"}{$pk})
     {
+      if($ttl_secs && (time - ${"${class}::Objects_By_Id_Loaded"}{$pk}) >= $ttl_secs)
+      {
+        delete ${"${class}::Objects_By_Id"}{$pk};
+        return CACHE_EXPIRED;
+      }
+
       return ${"${class}::Objects_By_Id"}{$pk};
     }
 
@@ -69,7 +97,13 @@ my $get_object = sub
 
     if(${"${class}::Objects_By_Key"}{$key_name}{$key_value})
     {
-      $save_object->(${"${class}::Objects_By_Key"}{$key_name}{$key_value});
+      if($ttl_secs && (time - ${"${class}::Objects_By_Key_Loaded"}{$key_name}{$key_value}) >= $ttl_secs)
+      {
+        delete ${"${class}::Objects_By_Key_Loaded"}{$key_name}{$key_value};
+        return undef; # cache expired
+      }
+
+      __xrdbopriv_save_object(${"${class}::Objects_By_Key"}{$key_name}{$key_value});
       return ${"${class}::Objects_By_Key"}{$key_name}{$key_value};
     }
 
@@ -85,13 +119,15 @@ sub load
   {
     my $pk = join(PK_SEP, grep { defined } map { $_[0]->$_() } $_[0]->meta->primary_key_columns);
 
-    if(my $object = $get_object->($_[0], $pk))
+    my $object = __xrdbopriv_get_object($_[0], $pk);
+
+    if($object)
     {
       $_[0] = $object;
       $_[0]->{STATE_IN_DB()} = 1;
       return 1;
     }
-    else
+    elsif(!(defined $object && $object == CACHE_EXPIRED))
     {
       foreach my $cols ($_[0]->meta->unique_keys)
       {
@@ -100,7 +136,7 @@ sub load
         my $key_value = join(UK_SEP, grep { defined($_) ? $_ : UNDEF } 
                              map { $_[0]->$_() } @$cols);
 
-        if(my $object = $get_object->($_[0], $key_name, $key_value))
+        if(my $object = __xrdbopriv_get_object($_[0], $key_name, $key_value))
         {
           $_[0] = $object;
           $_[0]->{STATE_IN_DB()} = 1;
@@ -113,7 +149,7 @@ sub load
   my $self = shift;
 
   my $ret = $self->SUPER::load(@_);
-  $save_object->($self)  if($ret);
+  __xrdbopriv_save_object($self)  if($ret);
 
   return $ret;
 }
@@ -129,7 +165,7 @@ sub save
 
   my $pk = join(PK_SEP, grep { defined } map { $self->$_() } $self->meta->primary_key_columns);
 
-  $save_object->($self);
+  __xrdbopriv_save_object($self);
 
   return $ret;
 }
@@ -171,6 +207,53 @@ sub forget_all
   return 1;
 }
 
+# Code borrowed from Cache::Cache
+my %Expiration_Units =
+(
+  map(($_,             1), qw(s sec secs second seconds)),
+  map(($_,            60), qw(m min mins minute minutes)),
+  map(($_,         60*60), qw(h hr hrs hour hours)),
+  map(($_,      60*60*24), qw(d day days)),
+  map(($_,    60*60*24*7), qw(w wk wks week weeks)),
+  map(($_,  60*60*24*365), qw(y yr yrs year years))
+);
+
+sub cache_expires_in
+{
+  my($class) = shift;
+
+  no strict 'refs';
+  return ${"${class}::Cache_Expires"} ||= 0  unless(@_);
+
+  my $arg = shift;
+
+  my $secs;
+
+  if($arg =~ /^now$/i)
+  {
+    $class->forget_all;
+    $secs = 0;
+  }
+  elsif($arg =~ /^never$/)
+  {
+    $secs = 0;
+  }
+  elsif($arg =~ /^\s*([+-]?(?:\d+|\d*\.\d*))\s*$/)
+  {
+    $secs = $arg;
+  }
+  elsif($arg =~ /^\s*([+-]?(?:\d+|\d*\.\d*))\s*(\w*)\s*$/ && exists $Expiration_Units{$2})
+  {
+    $secs = $Expiration_Units{$2} * $1;
+  }
+  else
+  {
+    Carp::croak("Invalid cache expiration time: '$arg'");
+  }
+
+  return ${"${class}::Cache_Expires"} = $secs;
+}
+
 sub remeber
 {
   my($self) = shift;
@@ -230,24 +313,59 @@ Rose::DB::Object::Cached - Memory cached object representation of a single row i
   $cat1->name('Blah');
   print $cat2->name; # prints "Blah"
 
+  # The object cache supports time-based expiration
+  Category->cache_expires_in('15 minutes');
+
+  $cat1 = Category->new(id => 123);
+  $cat1->save or $cat1->die;
+
+  $cat1->load; # loaded from cache
+
+  $cat2 = Category->new(id => 123);
+  $cat2->load; # loaded from cache
+
+  <15 minutes pass>
+
+  $cat3 = Category->new(id => 123);
+  $cat3->load; # NOT loaded from cache
+
   ...
 
 =head1 DESCRIPTION
 
-C<Rose::DB::Object::Cached> is a subclass of C<Rose::DB::Object> that is backed by a write-through memory cache.  Whenever an object is loaded from or saved to the database, it is cached in memory.  Any subsequent attempt to load an object of the same class with the same primary key or unique key value(s) will give you the cached object instead of loading from the database.
+C<Rose::DB::Object::Cached> is a subclass of L<Rose::DB::Object> that is backed by a write-through memory cache.  Whenever an object is loaded from or saved to the database, it is cached in memory.  Any subsequent attempt to load an object of the same class with the same primary key or unique key value(s) will give you the cached object instead of loading from the database.
 
 This means that I<modifications to an object will also modify all other objects in memory that have the same primary key.>  The L<synopsis|SYNOPSIS> above highlights this fact.
 
 This class is most useful for encapsulating "read-only" rows, or other data that is updated very infrequently.  In the C<Category> example above, it would be inefficient to repeatedly load category information in a long-running process (such as a mod_perl Apache web server) if that information changes infrequently.
 
-The memory cache can be cleared for an individual object or all objects of the same class.  There is no automatic cache expiration, however.  You must clear the cache manually as you see fit.
+The memory cache can be cleared for an individual object or all objects of the same class.  There is also support for simple time-based cache expiration.
 
-Only the methods that are overridden are documented here.  See the C<Rose::DB::Object> documentation for the rest.
+Only the methods that are overridden are documented here.  See the L<Rose::DB::Object> documentation for the rest.
 
 =head1 CLASS METHODS
 
 =over 4
 
+=item B<cache_expires_in [DURATION]>
+
+If called with no arguments, the cache expiration limit in seconds is returned.  
+
+If passed a DURATION, the cache expiration is set.  Valid formats for DURATION are in the form "NUMBER UNIT" where NUMBER is a positive number and UNIT is one of the following:
+
+    s sec secs second seconds
+    m min mins minute minutes
+    h hr hrs hour hours
+    d day days
+    w wk wks week weeks
+    y yr yrs year years
+
+All formats of the DURATION argument are converted to seconds.  Days are exactly 24 hours, weeks are 7 days, and years are 365 days.
+
+If an object was read from the database the specified number of seconds ago or earlier, it is purged from the cache and reloaded from the database.
+
+A C<cache_expires_in> value of undef or zero means that nothing will ever expire from the object cache for this class.  This is the default.
+
 =item B<forget_all>
 
 Clear the memory cache for all objects of this class.
@@ -262,10 +380,6 @@ Clear the memory cache for all objects of this class.
 
 Delete the current object from the memory cache.
 
-=item B<forget_all>
-
-Clear the memory cache for all objects of this class.
-
 =item B<load [PARAMS]>
 
 Load an object based on either a primary key or a unique key.
@@ -292,18 +406,21 @@ Save the current object to the memory cache I<without> saving it to the database
 
 =item B<save [PARAMS]>
 
-This method does the same thing as the C<Rose::DB::Object> method of the same name, except that it also saves the object to the memory cache if the save succeeds.  If it fails, the memory cache is not modified.
+This method does the same thing as the L<Rose::DB::Object> method of the same name, except that it also saves the object to the memory cache if the save succeeds.  If it fails, the memory cache is not modified.
 
 =back
 
 =head1 RESERVED METHODS
 
-In addition to the reserved methods listed in the C<Rose::DB::Object> documentation, the following method names are also reserved for objects that inherit from this class:
+In addition to the reserved methods listed in the L<Rose::DB::Object> documentation, the following method names are also reserved for objects that inherit from this class:
 
+    cache_expires_in
     forget
     forget_all
     remember
 
+If you have a column with one of these names, you must alias it.  See the L<Rose::DB::Object> documentation for more information on column aliasing and reserved methods.
+
 =head1 AUTHOR
 
 John C. Siracusa (siracusa@mindspring.com)
